==> estateplat-common-1.2.3-20180301.090929-36-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtLimitfield.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * 系统FR验证
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_xt_limitfield")
public class BdcXtLimitfield {
    @Id
    private String id;//主键
    private String workflowName;//工作流名称
    private String workflowId;//工作流ID
    private String workflowNodename;//工作流节点名称
    private String workflowNodeid;//工作流节点ID
    private String cptName;//CPT报表名称
    private String cptFieldName;//CPT字段名称
    private String tableFieldName;//数据库字段
    private String tableId;//数据库表
    private String tableFieldId;//数据库表的字段
    private String cptDesc;//cpt描述
    private String qllx;    //权利类型

    public String getCptDesc() {
        return cptDesc;
    }

    public void setCptDesc(String cptDesc) {
        this.cptDesc = cptDesc;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getWorkflowName() {
        return workflowName;
    }

    public void setWorkflowName(String workflowName) {
        this.workflowName = workflowName;
    }

    public String getWorkflowId() {
        return workflowId;
    }

    public void setWorkflowId(String workflowId) {
        this.workflowId = workflowId;
    }

    public String getWorkflowNodename() {
        return workflowNodename;
    }

    public void setWorkflowNodename(String workflowNodename) {
        this.workflowNodename = workflowNodename;
    }

    public String getWorkflowNodeid() {
        return workflowNodeid;
    }

    public void setWorkflowNodeid(String workflowNodeid) {
        this.workflowNodeid = workflowNodeid;
    }

    public String getCptName() {
        return cptName;
    }

    public void setCptName(String cptName) {
        this.cptName = cptName;
    }

    public String getCptFieldName() {
        return cptFieldName;
    }

    public void setCptFieldName(String cptFieldName) {
        this.cptFieldName = cptFieldName;
    }

    public String getTableFieldName() {
        return tableFieldName;
    }

    public void setTableFieldName(String tableFieldName) {
        this.tableFieldName = tableFieldName;
    }

    public String getTableId() {
        return tableId;
    }

    public void setTableId(String tableId) {
        this.tableId = tableId;
    }

    public String getTableFieldId() {
        return tableFieldId;
    }

    public void setTableFieldId(String tableFieldId) {
        this.tableFieldId = tableFieldId;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }
}

==> estateplat-common-1.2.4-20221101.020545-1107-sources.jar: cn/gtmap/estateplat/model/server/core/BdcXtLimitfield.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * 系统FR验证
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_xt_limitfield")
public class BdcXtLimitfield {
    @Id
    private String id;//主键
    private String workflowName;//工作流名称
    private String workflowId;//工作流ID
    private String workflowNodename;//工作流节点名称
    private String workflowNodeid;//工作流节点ID
    private String cptName;//CPT报表名称
    private String cptFieldName;//CPT字段名称
    private String tableFieldName;//数据库字段
    private String tableId;//数据库表
    private String tableFieldId;//数据库表的字段
    private String cptDesc;//cpt描述
    private String qllx;    //权利类型
    private String djzxdm;    //登记子项代码

    public String getCptDesc() {
        return cptDesc;
    }

    public void setCptDesc(String cptDesc) {
        this.cptDesc = cptDesc;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getWorkflowName() {
        return workflowName;
    }

    public void setWorkflowName(String workflowName) {
        this.workflowName = workflowName;
    }

    public String getWorkflowId() {
        return workflowId;
    }

    public void setWorkflowId(String workflowId) {
        this.workflowId = workflowId;
    }

    public String getWorkflowNodename() {
        return workflowNodename;
    }

    public void setWorkflowNodename(String workflowNodename) {
        this.workflowNodename = workflowNodename;
    }

    public String getWorkflowNodeid() {
        return workflowNodeid;
    }

    public void setWorkflowNodeid(String workflowNodeid) {
        this.workflowNodeid = workflowNodeid;
    }

    public String getCptName() {
        return cptName;
    }

    public void setCptName(String cptName) {
        this.cptName = cptName;
    }

    public String getCptFieldName() {
        return cptFieldName;
    }

    public void setCptFieldName(String cptFieldName) {
        this.cptFieldName = cptFieldName;
    }

    public String getTableFieldName() {
        return tableFieldName;
    }

    public void setTableFieldName(String tableFieldName) {
        this.tableFieldName = tableFieldName;
    }

    public String getTableId() {
        return tableId;
    }

    public void setTableId(String tableId) {
        this.tableId = tableId;
    }

    public String getTableFieldId() {
        return tableFieldId;
    }

    public void setTableFieldId(String tableFieldId) {
        this.tableFieldId = tableFieldId;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDjzxdm() {
        return djzxdm;
    }

    public void setDjzxdm(String djzxdm) {
        this.djzxdm = djzxdm;
    }
}
